@@ -14,5 +14,5 @@ class DjangoAppRegistry(PluginManager):
     """
 
 
-def get_app_configs(project_type):
+def get_plugin_app_configs(project_type):
     return six.itervalues(DjangoAppRegistry.get_available_plugins(project_type))
